@@ -7,7 +7,7 @@ router.APIRootView = views.UCBoxPluginRootView
 
 router.register(r'numbers', views.NumberViewSet)
 router.register(r'trunks', views.TrunkViewSet)
-router.register(r"clusters", views.ClusterViewSet)
+router.register(r"UCClusters", views.UCClusterViewSet)
 router.register(r"devicepools", views.DevicePoolViewSet)
 
 
