@@ -1,6 +1,6 @@
 from rest_framework.routers import APIRootView
 from .. import filters
-from ..models import Number, Trunk, Cluster, DevicePool
+from ..models import Number, Trunk, UCCluster, DevicePool
 from netbox.api.views import ModelViewSet
 from . import serializers
 
@@ -23,10 +23,10 @@ class TrunkViewSet(ModelViewSet):
     serializer_class = serializers.TrunkSerializer
     filterset_class = filters.TrunkFilterSet
 
-class ClusterViewSet(ModelViewSet):
-    queryset = Cluster.objects.prefetch_related('tenant', 'tags')
-    serializer_class = serializers.ClusterSerializer
-    filterset_class = filters.ClusterFilterSet
+class UCClusterViewSet(ModelViewSet):
+    queryset = UCCluster.objects.prefetch_related('tenant', 'tags')
+    serializer_class = serializers.UCClusterSerializer
+    filterset_class = filters.UCClusterFilterSet
 
 class DevicePoolViewSet(ModelViewSet):
     queryset = DevicePool.objects.prefetch_related('tenant', 'region', 'tags')
